@@ -40,7 +40,7 @@
 /*use insert sort - it's the fastest for small and almost sorted arrays (our case)*/
 #define SORT (3) //1 - Quick sort   2 - Shell sort  3- insert sort  other - bubble sort
 
-#define TH		(80) // treshold = 1/80 of focus sharpness value
+#define _TH_		(80) // default treshold = 1/80 of focus sharpness value
 
 #define FLAT 		(0)
 #define LOCAL_MAX	(1)
@@ -61,15 +61,25 @@ static int ACweight[64] = {
 	7,7,7,7,7,7,7,7
 };
 
-void initFocusData (struct focusData *AFdata) 
+struct focusData *initFocusData (int f_max, int f_min, int step, int id) 
 {
-	memset(AFdata,0,sizeof(struct focusData));
-	AFdata->right=255;
-	AFdata->left=8; /*start with focus at 8*/
-	AFdata->focus=-1;
-	AFdata->focus_wait=0;
+	struct focusData *AFdata = g_new0(struct focusData, 1);
+	if(AFdata == NULL) 
+		return (AFdata);
+    AFdata->id = id;
+	AFdata->f_max = f_max;
+	AFdata->f_min = f_min;
+	AFdata->f_step = step;
+	AFdata->i_step = (f_max + 1 - f_min)/32;
+	if(AFdata->i_step <= step) AFdata->i_step = step * 2;
+	//g_printf("focus step:%i\n", AFdata->i_step);
+	AFdata->right = f_max;
+	AFdata->left = f_min + AFdata->i_step; /*start with focus at 8*/
+	AFdata->focus = -1;
+	AFdata->focus_wait = 0;
 	memset(sumAC,0,64);
 	/*all other values are 0 */
+	return (AFdata);
 }
 
 #if (SORT == 1)
@@ -177,7 +187,6 @@ static int Sort(struct focusData *AFdata, int size)
 		g_printerr("WARNING: focus array size=%d exceeds 20\n",size);
 		size = 10;
 	}
-	//ULLONG tm1 = ns_time();
 #if (SORT == 1)
 	q_sort(AFdata, 0, size);
 #elif (SORT == 2)
@@ -297,8 +306,11 @@ int getSharpness (BYTE* img, int width, int height, int t)
 
 static int checkFocus(struct focusData *AFdata) 
 {
+	/*change treshold according to sharpness*/
+	int TH = _TH_; 
+	//if(AFdata->focus_sharpness < (5 * _TH_)) TH = _TH_ * 4 ;
 	
-	if (AFdata->step<=8) 
+	if (AFdata->step <= AFdata->i_step) 
 	{
 		if (abs((AFdata->sharpLeft-AFdata->focus_sharpness)<(AFdata->focus_sharpness/TH)) && 
 			(abs(AFdata->sharpRight-AFdata->focus_sharpness)<(AFdata->focus_sharpness/TH))) 
@@ -348,8 +360,9 @@ static int checkFocus(struct focusData *AFdata)
 
 int getFocusVal (struct focusData *AFdata) 
 {
-	int step = 20;
-	int step2 = 2;
+	int step = AFdata->i_step * 2;
+	int step2 = AFdata->i_step / 2;
+	if (step2 <= 0 ) step2 = 1;
 	int focus=0;
 	
 	switch (AFdata->flag) 
@@ -361,72 +374,75 @@ int getFocusVal (struct focusData *AFdata)
 			AFdata->ind = 10;
 		}
 		
-		case 0: /*sample left to right*/
+		case 0: /*sample left to right at higher step*/
 			AFdata->arr_sharp[AFdata->ind] = AFdata->sharpness;
 			AFdata->arr_foc[AFdata->ind] = AFdata->focus;
-			if (AFdata->focus > (AFdata->right - step)) 
+			/*reached max focus value*/
+			if (AFdata->focus >= AFdata->right ) 
 			{	/*get left and right from arr_sharp*/
 				focus=Sort(AFdata,AFdata->ind);
 				/*get a window around the best value*/
 				AFdata->left = (focus- step/2);
 				AFdata->right = (focus + step/2);
-				if (AFdata->left < 0) AFdata->left=0;
-				if (AFdata->right > 255) AFdata->right=255;
+				if (AFdata->left < AFdata->f_min) AFdata->left = AFdata->f_min;
+				if (AFdata->right > AFdata->f_max) AFdata->right = AFdata->f_max;
 				AFdata->focus = AFdata->left;
 				AFdata->ind=0;
 				AFdata->flag = 1;
 			} 
-			else 
+			else /*increment focus*/
 			{ 
 				AFdata->focus=AFdata->arr_foc[AFdata->ind] + step; /*next focus*/
-				AFdata->ind=AFdata->ind+1;;
+				AFdata->ind++;
 				AFdata->flag = 0;
 			}
 			break;
-		case 1: /*sample left to right*/ 
+		case 1: /*sample left to right at lower step - fine tune*/ 
 			AFdata->arr_sharp[AFdata->ind] = AFdata->sharpness;
 			AFdata->arr_foc[AFdata->ind] = AFdata->focus;
-			if (AFdata->focus > (AFdata->right - step2)) 
+			/*reached window max focus*/
+			if (AFdata->focus >= AFdata->right ) 
 			{	/*get left and right from arr_sharp*/
 				focus=Sort(AFdata,AFdata->ind);
 				/*get the best value*/
 				AFdata->focus = focus;
 				AFdata->focus_sharpness = AFdata->arr_sharp[AFdata->ind];
-				AFdata->step = 8; /*first step for focus tracking*/
+				AFdata->step = AFdata->i_step; /*first step for focus tracking*/
 				AFdata->focusDir = FLAT; /*no direction for focus*/
 				AFdata->flag = 2;
 			}
-			else 
+			else /*increment focus*/
 			{ 
 				AFdata->focus=AFdata->arr_foc[AFdata->ind] + step2; /*next focus*/
-				AFdata->ind=AFdata->ind+1;;
+				AFdata->ind++;
 				AFdata->flag = 1;
 			}
 			break;
 		case 2: /* set treshold in order to sharpness*/
 			if (AFdata->setFocus) 
-			{
+			{	
+				/*reset*/
 				AFdata->setFocus = 0;
 				AFdata->flag= 0;
-				AFdata->right = 255;
-				AFdata->left = 8;
+				AFdata->right = AFdata->f_max;
+				AFdata->left = AFdata->f_min + AFdata->i_step;
 				AFdata->ind = 0;
 			}
 			else 
 			{
 				/*track focus*/
-				AFdata->focus_sharpness=AFdata->sharpness;
-				AFdata->flag= 3;
-				AFdata->sharpLeft=0;
-				AFdata->sharpRight=0;
-				AFdata->focus+=AFdata->step; /*check right*/
+				AFdata->focus_sharpness = AFdata->sharpness;
+				AFdata->flag = 3;
+				AFdata->sharpLeft = 0;
+				AFdata->sharpRight = 0;
+				AFdata->focus += AFdata->step; /*check right*/
 			}
 			break;
 		case 3:
 			/*track focus*/
-			AFdata->flag= 4;
-			AFdata->sharpRight=AFdata->sharpness;
-			AFdata->focus-=(2*AFdata->step); /*check left*/
+			AFdata->flag = 4;
+			AFdata->sharpRight = AFdata->sharpness;
+			AFdata->focus -= (2*AFdata->step); /*check left*/
 			break;
 		case 4:
 			/*track focus*/
@@ -437,26 +453,35 @@ int getFocusVal (struct focusData *AFdata)
 			{
 				case LOCAL_MAX:
 					AFdata->focus += AFdata->step; /*return to orig. focus*/
-					AFdata->step = 8;
+					AFdata->step = AFdata->i_step;
 					AFdata->flag = 2;
 					break;
 					
 				case FLAT:
 					if(AFdata->focusDir == FLAT) 
 					{
-						AFdata->focus += AFdata->step; /*return to orig. focus*/
-						AFdata->step = 8;
+						AFdata->step = AFdata->i_step;
+						if(AFdata->focus_sharpness < 4 * _TH_) 
+						{
+							/* 99% chance we lost focus     */	
+							/* move focus to half the range */
+							AFdata->focus = AFdata->f_max / 2;
+						}
+						else
+						{
+							AFdata->focus += AFdata->step; /*return to orig. focus*/
+						}
 						AFdata->flag = 2;
 					}
 					else if (AFdata->focusDir == RIGHT) 
 					{
 						AFdata->focus += 2*AFdata->step; /*go right*/
-						AFdata->step = 8;
+						AFdata->step = AFdata->i_step;
 						AFdata->flag = 2;
 					} 
 					else 
 					{	/*go left*/
-						AFdata->step = 8;
+						AFdata->step = AFdata->i_step;
 						AFdata->flag = 2;
 					}
 					break;
@@ -473,16 +498,16 @@ int getFocusVal (struct focusData *AFdata)
 					
 				case INCSTEP:
 					AFdata->focus += AFdata->step; /*return to orig. focus*/
-					AFdata->step = 16;
+					AFdata->step = 2 * AFdata->i_step;
 					AFdata->flag = 2;
 					break;
 			}
 			break;
 	}
 	/*clip focus, right and left*/
-	AFdata->focus=(AFdata->focus>255)?255:((AFdata->focus<0)?0:AFdata->focus);
-	AFdata->right=(AFdata->right>255)?255:((AFdata->right<0)?0:AFdata->right);
-	AFdata->left=(AFdata->left>255)?255:((AFdata->left<0)?0:AFdata->left);
+	AFdata->focus=(AFdata->focus > AFdata->f_max) ? AFdata->f_max : ((AFdata->focus < AFdata->f_min) ? AFdata->f_min : AFdata->focus);
+	AFdata->right=(AFdata->right > AFdata->f_max) ? AFdata->f_max : ((AFdata->right < AFdata->f_min) ? AFdata->f_min : AFdata->right);
+	AFdata->left =(AFdata->left > AFdata->f_max) ? AFdata->f_max : ((AFdata->left < AFdata->f_min) ? AFdata->f_min : AFdata->left);
 
 	return AFdata->focus;
 }
