@@ -27,21 +27,33 @@
 #include <gtk/gtk.h>
 #include "guvcview.h"
 
+#ifndef GDK_WebCam
+#define GDK_WebCam 0x1008ff8f
+#endif
+
+void
+WARN_DIALOG(const char *warn_title, const char* warn_msg, struct ALL_DATA *all_data);
+
 void 
 ERR_DIALOG(const char *err_title, const char* err_msg, struct ALL_DATA *all_data);
 
+/* sound controls*/
+void 
+set_sensitive_snd_contrls (const int flag, struct GWIDGET *gwidget);
+
+/*video controls*/
+void 
+set_sensitive_vid_contrls (const int flag, const int sndEnable, struct GWIDGET *gwidget);
+
 gint
 delete_event (GtkWidget *widget, GdkEventConfigure *event, void *data);
 
-void 
-set_sensitive_snd_contrls (const int flag, struct GWIDGET *gwidget);
-
-void 
-set_sensitive_vid_contrls (const int flag, const int sndEnable, struct GWIDGET *gwidget);
-
 void 
 set_sensitive_img_contrls (const int flag, struct GWIDGET *gwidget);
 
+gboolean
+key_pressed (GtkWidget *win, GdkEventKey *event, struct ALL_DATA *all_data);
+
 void
 vidClose (struct ALL_DATA *all_data);
 
@@ -60,18 +72,15 @@ autofocus_changed (GtkToggleButton * toggle, struct ALL_DATA *all_data);
 void
 check_changed (GtkToggleButton * toggle, struct ALL_DATA *all_data);
 
-void
-reversePan_changed (GtkToggleButton * toggle, struct ALL_DATA *all_data);
-
-void
-bayer_changed (GtkToggleButton * toggle, struct ALL_DATA *all_data);
-
 void
 pix_ord_changed (GtkComboBox * combo, struct ALL_DATA *all_data);
 
 void
 combo_changed (GtkComboBox * combo, struct ALL_DATA *all_data);
 
+void
+button_clicked (GtkButton * Button, struct ALL_DATA *all_data);
+
 void
 VidFormat_changed (GtkComboBox * VidFormat, struct ALL_DATA *all_data);
 
@@ -79,7 +88,10 @@ void
 setfocus_clicked (GtkButton * FocusButton, struct ALL_DATA *all_data);
 
 void
-PanTilt_clicked (GtkButton * PanTilt, struct ALL_DATA *all_data);
+button_PanTilt1_clicked (GtkButton * Button, struct ALL_DATA *all_data);
+
+void
+button_PanTilt2_clicked (GtkButton * Button, struct ALL_DATA *all_data);
 
 void
 quitButton_clicked (GtkButton * quitButton, struct ALL_DATA *all_data);
@@ -91,7 +103,7 @@ void
 resolution_changed (GtkComboBox * Resolution, struct ALL_DATA *all_data);
 
 void
-ImpType_changed(GtkComboBox * ImpType, struct ALL_DATA *all_data);
+InpType_changed(GtkComboBox * ImpType, struct ALL_DATA *all_data);
 
 void
 FrameRate_changed (GtkComboBox * FrameRate, struct ALL_DATA *all_data);
@@ -141,6 +153,9 @@ capture_vid (GtkToggleButton *VidButt, struct ALL_DATA *all_data);
 void
 ProfileButton_clicked (GtkButton * SProfileButton, struct ALL_DATA *all_data);
 
+void
+DefaultsButton_clicked (GtkButton * DefaultsButton, struct ALL_DATA *all_data);
+
 void *
 split_avi(void *data);
 
