@@ -63,6 +63,7 @@ int initGlobals (struct GLOBAL *global)
 	g_snprintf(global->WVcaption,10,"GUVCVIdeo");
 
 	global->videoBuff = NULL;
+	global->video_buff_size = VIDBUFF_SIZE;
 	
 	global->stack_size=TSTACK;
 	
@@ -81,7 +82,7 @@ int initGlobals (struct GLOBAL *global)
 	global->imgFormat=0; /* 0 -JPG 1-BMP 2-PNG*/
 	global->VidCodec=0; /*0-"MJPG"  1-"YUY2" 2-"DIB "(rgb32) 3-...*/ 
 	global->AVI_MAX_LEN=AVI_MAX_SIZE; /* ~2 Gb*/    
-	global->snd_begintime=0;/*begin time for audio capture*/
+	global->av_drift=0;
 	global->currtime=0;
 	global->lasttime=0;
 	global->Vidstarttime=0;
@@ -118,6 +119,8 @@ int initGlobals (struct GLOBAL *global)
 	global->fps_num = DEFAULT_FPS_NUM;
 	global->bpp = 0; //current bytes per pixel
 	global->hwaccel = 1; //use hardware acceleration
+	global->desktop_w = 0;
+	global->desktop_h = 0;
 	global->cap_meth = IO_MMAP;//default mmap(1) or read(0)
 	global->flg_cap_meth = FALSE;
 	global->width = DEFAULT_WIDTH;
