@@ -50,6 +50,7 @@ struct GLOBAL
 	GCond   *IO_cond;      //IO thread semaphore
 	
 	VidBuff *videoBuff;    //video Buffer
+	int video_buff_size;   //size in frmaes of video buffer
 	
 	char *videodevice;     // video device (def. /dev/video0)
 	char *confPath;        //configuration file path
@@ -66,7 +67,7 @@ struct GLOBAL
 	BYTE *jpeg;            // jpeg buffer
 
 	ULONG AVI_MAX_LEN;     //avi max length
-	DWORD snd_begintime;   //begin time for audio capture
+	int64_t av_drift;      // amount of A/V time correction
 	DWORD currtime;
 	DWORD lasttime;
 	UINT64 Vidstarttime;    //video start time
@@ -101,6 +102,7 @@ struct GLOBAL
 	int FpsCount;          //frames counter for fps calc
 	int timer_id;          //fps count timer
 	int image_timer_id;    //auto image capture timer
+    int udev_timer_id;     //timer id for udev device events check
 	int disk_timer_id;     //timer id for disk check (free space)
 	int image_timer;       //auto image capture time
 	int image_npics;       //number of captures
@@ -108,6 +110,8 @@ struct GLOBAL
 	int fps_num;           //fps numerator (usually 1)
 	int bpp;               //current bytes per pixel
 	int hwaccel;           //use hardware acceleration
+	int desktop_w;         //Desktop width
+	int desktop_h;         //Desktop height
 	int width;             //frame width
 	int height;            //frame height
 	int winwidth;          //control windoe width
