@@ -127,7 +127,6 @@ int main(int argc, char *argv[])
 	GtkWidget *buttons_table;
 	GtkWidget *profile_labels;
 	GtkWidget *capture_labels;
-	GtkWidget *quitButton;
 	GtkWidget *SProfileButton;
 	GtkWidget *LProfileButton;
     GtkWidget *DefaultsButton;
@@ -226,7 +225,7 @@ int main(int argc, char *argv[])
 
 			case VDIN_DYNCTRL_ERR: //uvc extension controls error - EACCES (needs root user)
 				ERR_DIALOG (N_("Guvcview error:\n\nUVC Extension controls"),
-					N_("An error ocurred while adding extension\ncontrols to the UVC driver\nMake sure you run guvcview as root (or sudo)."),
+					N_("An error occurred while adding extension\ncontrols to the UVC driver\nMake sure you run guvcview as root (or sudo)."),
 					&all_data);
 				break;
 				
@@ -306,7 +305,7 @@ int main(int argc, char *argv[])
 				
 			case VDIN_QUERYCAP_ERR:
 				ERR_DIALOG (N_("Guvcview error:\n\nCouldn't query device capabilities"),
-					N_("Make sure the device driver suports v4l2."),
+					N_("Make sure the device driver supports v4l2."),
 					&all_data);
 				break;
 			case VDIN_READ_ERR:
@@ -411,7 +410,7 @@ int main(int argc, char *argv[])
 		
 	gtk_widget_show(HButtonBox);
 	
-	quitButton=gtk_button_new_from_stock(GTK_STOCK_QUIT);
+	gwidget->quitButton=gtk_button_new_from_stock(GTK_STOCK_QUIT);
 	SProfileButton=gtk_button_new_from_stock(GTK_STOCK_SAVE);
 	LProfileButton=gtk_button_new_from_stock(GTK_STOCK_OPEN);
     DefaultsButton=gtk_button_new_with_label(_("Defaults"));
@@ -516,8 +515,8 @@ int main(int argc, char *argv[])
 	{
 		QButton_Img = gtk_image_new_from_file (pix6path);
 		
-		gtk_button_set_image(GTK_BUTTON(quitButton),QButton_Img);
-		gtk_button_set_image_position(GTK_BUTTON(quitButton),GTK_POS_TOP);
+		gtk_button_set_image(GTK_BUTTON(gwidget->quitButton),QButton_Img);
+		gtk_button_set_image_position(GTK_BUTTON(gwidget->quitButton),GTK_POS_TOP);
 		//gtk_widget_show (QButton_Img);
 	}
 
@@ -530,14 +529,14 @@ int main(int argc, char *argv[])
 	gtk_box_pack_start(GTK_BOX(HButtonBox),SProfileButton,TRUE,TRUE,2);
 	gtk_box_pack_start(GTK_BOX(HButtonBox),LProfileButton,TRUE,TRUE,2);
     gtk_box_pack_start(GTK_BOX(HButtonBox),DefaultsButton,TRUE,TRUE,2);
-	gtk_box_pack_start(GTK_BOX(HButtonBox),quitButton,TRUE,TRUE,2);
+	gtk_box_pack_start(GTK_BOX(HButtonBox),gwidget->quitButton,TRUE,TRUE,2);
 
 	gtk_widget_show_all (LProfileButton);
 	gtk_widget_show_all (SProfileButton);
     gtk_widget_show_all (DefaultsButton);
-	gtk_widget_show_all (quitButton);
+	gtk_widget_show_all (gwidget->quitButton);
 
-	g_signal_connect (GTK_BUTTON(quitButton), "clicked",
+	g_signal_connect (GTK_BUTTON(gwidget->quitButton), "clicked",
 		G_CALLBACK (quitButton_clicked), &all_data);
 	
 	gboolean SProfile = TRUE;
@@ -572,17 +571,20 @@ int main(int argc, char *argv[])
 	gtk_container_add (GTK_CONTAINER (gwidget->mainwin), gwidget->boxv);
 	
 	gtk_widget_show (gwidget->mainwin);
-	
+    
+     /*Add udev device monitoring timer*/
+    global->udev_timer_id=g_timeout_add( 500, check_v4l2_udev_events, &all_data);
+    
 	if (!control_only) /*control_only exclusion*/
 	{
-		/*------------------ Creating the main loop (video) thread ---------------*/
+		/*------------------ Creating the video thread ---------------*/
 		GError *err1 = NULL;
 
 		if( (video_thread = g_thread_create_full((GThreadFunc) main_loop, 
 			(void *) &all_data,       //data - argument supplied to thread
 			global->stack_size,       //stack size
 			TRUE,                     //joinable
-			FALSE,                    //bound
+			TRUE,                     //bound
 			G_THREAD_PRIORITY_NORMAL, //priority - no priority for threads in GNU-Linux
 			&err1)                    //error
 		) == NULL)
@@ -600,7 +602,7 @@ int main(int argc, char *argv[])
 		if(global->image_timer)
 		{
 			global->image_timer_id=g_timeout_add(global->image_timer*1000,
-				Image_capture_timer,&all_data);
+				Image_capture_timer, &all_data);
 			set_sensitive_img_contrls(FALSE, gwidget);/*disable image controls*/
 		}
 		/*--------------------- video capture from start ---------------------------*/
@@ -626,7 +628,7 @@ int main(int argc, char *argv[])
 					(void *) &all_data,       //data - argument supplied to thread
 					global->stack_size,       //stack size
 					TRUE,                     //joinable
-					FALSE,                    //bound
+					TRUE,                     //bound
 					G_THREAD_PRIORITY_NORMAL, //priority - no priority for threads in GNU-Linux
 					&err1)                    //error
 				) == NULL)
