@@ -30,6 +30,8 @@
 
 #include "defs.h"
 #include "globals.h"
+#include "vcodecs.h"
+#include "acodecs.h"
 #include "string_utils.h"
 #include "avilib.h"
 #include "v4l2uvc.h"
@@ -40,7 +42,11 @@ writeConf(struct GLOBAL *global, char *videodevice)
 {
 	int ret=0;
 	FILE *fp;
-	
+    //use c locale - make sure floats are writen with a "." and not a ","
+    setlocale(LC_NUMERIC, "C");
+    //get pointers to codec properties
+    vcodecs_data *vcodec_defaults = get_codec_defaults(global->VidCodec);
+    acodecs_data *acodec_defaults = get_aud_codec_defaults(get_ind_by4cc(global->Sound_Format));
 	// write to tmp file then rename after sucessfull fsync
 	// using fsync avois data loss on system crash 
 	// see: https://bugs.launchpad.net/ubuntu/+source/linux/+bug/317781/comments/54
@@ -63,7 +69,7 @@ writeConf(struct GLOBAL *global, char *videodevice)
 		g_fprintf(fp,"vpane=%i\n",global->boxvsize);
 		g_fprintf(fp,"#spin button behavior: 0-non editable 1-editable\n");
 		g_fprintf(fp,"spinbehave=%i\n", global->spinbehave);
-		g_fprintf(fp,"# mode video format 'yuvy' 'yvyu' 'uyvy' 'yyuv' 'yu12' 'yv12' 'nv12' 'nv21' 'nv16' 'nv61' 'y41p' 'grey' 's501' 's505' 's508' 'gbrg' 'grbg' 'ba81' 'rggb' 'rgb3' 'bgr3' 'jpeg' 'mjpg'(default)\n");
+		g_fprintf(fp,"# mode video format 'yuvy' 'yvyu' 'uyvy' 'yyuv' 'yu12' 'yv12' 'nv12' 'nv21' 'nv16' 'nv61' 'y41p' 'grey' 'y16 ' 's501' 's505' 's508' 'gbrg' 'grbg' 'ba81' 'rggb' 'rgb3' 'bgr3' 'jpeg' 'mjpg'(default)\n");
 		g_fprintf(fp,"mode='%s'\n",global->mode);
 		g_fprintf(fp,"# frames per sec. - hardware supported - default( %i )\n",DEFAULT_FPS);
 		g_fprintf(fp,"fps='%d/%d'\n",global->fps_num,global->fps);
@@ -96,23 +102,46 @@ writeConf(struct GLOBAL *global, char *videodevice)
 		g_fprintf(fp,"snd_delay=%llu\n",(unsigned long long) global->Sound_delay);
 		g_fprintf(fp,"# Sound Format (PCM=1 (0x0001) MP2=80 (0x0050)\n");
 		g_fprintf(fp,"snd_format=%i\n",global->Sound_Format);
-		//g_fprintf(fp,"# Sound bit Rate used by mpeg audio default=160 Kbps\n");
-		//g_fprintf(fp,"#other values: 48 56 64 80 96 112 128 160 192 224 384\n");
-		//g_fprintf(fp,"snd_bitrate=%i\n",global->Sound_bitRate);
 		//g_fprintf(fp,"#Pan Step in degrees, Default=2\n");
 		//g_fprintf(fp,"Pan_Step=%i\n",global->PanStep);
 		//g_fprintf(fp,"#Tilt Step in degrees, Default=2\n");
 		//g_fprintf(fp,"Tilt_Step=%i\n",global->TiltStep);
 		g_fprintf(fp,"# video filters: 0 -none 1- flip 2- upturn 4- negate 8- mono (add the ones you want)\n");
 		g_fprintf(fp,"frame_flags=%i\n",global->Frame_Flags);
-		g_fprintf(fp,"# Image capture Full Path\n");
-		g_fprintf(fp,"image_path='%s/%s'\n",global->imgFPath[1],global->imgFPath[0]);
 		g_fprintf(fp,"# Auto Image naming (filename-n.ext)\n");
 		g_fprintf(fp,"image_inc=%d\n",global->image_inc);
+		g_fprintf(fp,"# Image capture Full Path\n");
+		g_fprintf(fp,"image_path='%s/%s'\n",global->imgFPath[1],global->imgFPath[0]);
 		g_fprintf(fp,"# Video capture Full Path\n");
 		g_fprintf(fp,"video_path='%s/%s'\n",global->vidFPath[1],global->vidFPath[0]);
 		g_fprintf(fp,"# control profiles Full Path\n");
 		g_fprintf(fp,"profile_path='%s/%s'\n",global->profile_FPath[1],global->profile_FPath[0]);
+        g_fprintf(fp, "# audio codec properties (remove for default values\n");
+        g_fprintf(fp, "acodec_bit_rate=%d\n",acodec_defaults->bit_rate);
+		g_fprintf(fp, "# video codec (%s) properties (remove for default values\n", vcodec_defaults->compressor);
+		g_fprintf(fp, "vcodec_bit_rate=%d\n",vcodec_defaults->bit_rate);
+		g_fprintf(fp, "vcodec_fps=%d\n",vcodec_defaults->fps);
+		g_fprintf(fp, "vcodec_qmax=%d\n",vcodec_defaults->qmax);
+		g_fprintf(fp, "vcodec_qmin=%d\n",vcodec_defaults->qmin);
+		g_fprintf(fp, "vcodec_max_qdiff=%d\n",vcodec_defaults->max_qdiff);
+		g_fprintf(fp, "vcodec_dia=%d\n",vcodec_defaults->dia);
+		g_fprintf(fp, "vcodec_pre_dia=%d\n",vcodec_defaults->pre_dia);
+		g_fprintf(fp, "vcodec_pre_me=%d\n",vcodec_defaults->pre_me);
+		g_fprintf(fp, "vcodec_me_pre_cmp=%d\n",vcodec_defaults->me_pre_cmp);
+		g_fprintf(fp, "vcodec_me_cmp=%d\n",vcodec_defaults->me_cmp);
+		g_fprintf(fp, "vcodec_me_sub_cmp=%d\n",vcodec_defaults->me_sub_cmp);
+		g_fprintf(fp, "vcodec_last_pred=%d\n",vcodec_defaults->last_pred);
+		g_fprintf(fp, "vcodec_gop_size=%d\n",vcodec_defaults->gop_size);
+		g_fprintf(fp, "vcodec_qcompress=%.2f\n",vcodec_defaults->qcompress);
+		g_fprintf(fp, "vcodec_qblur=%.2f\n",vcodec_defaults->qblur);
+		g_fprintf(fp, "vcodec_subq=%d\n",vcodec_defaults->subq);
+		g_fprintf(fp, "vcodec_framerefs=%d\n",vcodec_defaults->framerefs);
+		g_fprintf(fp, "vcodec_mb_decision=%d\n",vcodec_defaults->mb_decision);
+		g_fprintf(fp, "vcodec_trellis=%d\n",vcodec_defaults->trellis);
+		g_fprintf(fp, "vcodec_me_method=%d\n",vcodec_defaults->me_method);
+		g_fprintf(fp, "vcodec_mpeg_quant=%d\n",vcodec_defaults->mpeg_quant);
+		g_fprintf(fp, "vcodec_max_b_frames=%d\n",vcodec_defaults->max_b_frames);
+		g_fprintf(fp, "vcodec_flags=%d\n",vcodec_defaults->flags);
 		printf("write %s OK\n",global->confPath);
 		
 		//flush stream buffers to filesystem
@@ -136,7 +165,10 @@ writeConf(struct GLOBAL *global, char *videodevice)
 		ret=-2;
 	}
 	g_free(tmpfile);
-	
+    
+    //return to system locale
+    setlocale(LC_NUMERIC, "");
+    
 	return ret;
 }
 
@@ -177,7 +209,7 @@ readConf(struct GLOBAL *global)
 		FALSE,                         /* scope 0 fallback */
 		TRUE                           /* store int64 */
 	};
-
+    
 	int fd = g_open (global->confPath, O_RDONLY, 0);
 	
 	if (fd < 0 )
@@ -190,6 +222,13 @@ readConf(struct GLOBAL *global)
 		scanner = g_scanner_new (&config);
 		g_scanner_input_file (scanner, fd);
 		scanner->input_name = global->confPath;
+		//temp codec values
+		int ac_bit_rate =-1, vc_bit_rate=-1, vc_fps=-1, vc_qmax=-1, vc_qmin=-1, vc_max_qdiff=-1, vc_dia=-1;
+		int vc_pre_dia=-1, vc_pre_me=-1, vc_me_pre_cmp=-1, vc_me_cmp=-1, vc_me_sub_cmp=-1, vc_last_pred=-1;
+		int vc_gop_size=-1, vc_subq=-1, vc_framerefs=-1, vc_mb_decision=-1, vc_trellis=-1, vc_me_method=-1;
+		int vc_mpeg_quant=-1, vc_max_b_frames=-1, vc_flags=-1;
+		float vc_qcompress=-1, vc_qblur=-1;
+		
 		
 		for (ttype = g_scanner_get_next_token (scanner);
 			ttype != G_TOKEN_EOF;
@@ -263,8 +302,26 @@ readConf(struct GLOBAL *global)
 							{
 								global->imgFPath = splitPath(scanner->value.v_string,global->imgFPath);
 								/*get the file type*/
+		
 								global->imgFormat = check_image_type(global->imgFPath[0]);
 							}
+							else
+							{
+							    /* check if new file != old file */
+							    gchar * newPath = g_strjoin ("/", global->imgFPath[1], global->imgFPath[0], NULL);
+							    //printf("image path: %s\n old path: %s\n", newPath, scanner->value.v_string);
+							    if(g_strcmp0(scanner->value.v_string, newPath) !=0) 
+	                            {
+	                                /* reset counter */
+	                                //printf("reset counter from: %i\n", global->image_inc);
+	                                if(global->image_inc > 0) 
+	                                {
+	                                    global->image_inc = 1;
+	                                    g_snprintf(global->imageinc_str,20,_("File num:%d"),global->image_inc);  
+	                                }
+	                            }
+	                            g_free(newPath);
+							}
 						}
 						else if ((g_strcmp0(name,"video_path")==0) || (g_strcmp0(name,"avi_path")==0)) 
 						{
@@ -425,11 +482,98 @@ readConf(struct GLOBAL *global)
 						}
 						else if (g_strcmp0(name,"image_inc")==0) 
 						{
-							if(global->image_timer <= 0)
-							{
-								global->image_inc = (DWORD) scanner->value.v_int;
-								g_snprintf(global->imageinc_str,20,_("File num:%d"),global->image_inc);
-							}
+							global->image_inc = (DWORD) scanner->value.v_int;
+							if((global->image_timer > 0) && (global->image_inc <= 0))
+							    global->image_inc = 1;
+							g_snprintf(global->imageinc_str,20,_("File num:%d"),global->image_inc);
+						}
+						else if (g_strcmp0(name,"acodec_bit_rate")==0) 
+						{
+						    ac_bit_rate = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_bit_rate")==0) 
+						{
+						    vc_bit_rate = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_fps")==0) 
+						{
+						    vc_fps = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_qmax")==0) 
+						{
+						    vc_qmax = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_qmin")==0) 
+						{
+						    vc_qmin = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_max_qdiff")==0) 
+						{
+						    vc_max_qdiff = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_dia")==0) 
+						{
+						    vc_dia = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_pre_dia")==0) 
+						{
+						    vc_pre_dia = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_pre_me")==0) 
+						{
+						    vc_pre_me= scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_me_pre_cmp")==0) 
+						{
+						    vc_me_pre_cmp = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_me_cmp")==0) 
+						{
+						    vc_me_cmp = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_me_sub_cmp")==0) 
+						{
+						    vc_me_sub_cmp = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_last_pred")==0) 
+						{
+						    vc_last_pred = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_gop_size")==0) 
+						{
+						    vc_gop_size = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_subq")==0) 
+						{
+						    vc_subq = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_framerefs")==0) 
+						{
+						    vc_framerefs = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_mb_decision")==0) 
+						{
+						    vc_mb_decision = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_trellis")==0) 
+						{
+						    vc_trellis = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_me_method")==0) 
+						{
+						    vc_me_method = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_mpeg_quant")==0) 
+						{
+						    vc_mpeg_quant = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_max_b_frames")==0) 
+						{
+						    vc_max_b_frames = scanner->value.v_int;
+						}
+						else if (g_strcmp0(name,"vcodec_flags")==0) 
+						{
+						    vc_flags = scanner->value.v_int;
 						}
 						else
 						{
@@ -440,7 +584,16 @@ readConf(struct GLOBAL *global)
 					}
 					else if (ttype==G_TOKEN_FLOAT)
 					{
-						printf("unexpected float value (%f) for %s\n", scanner->value.v_float, name);
+					    if (g_strcmp0(name,"vcodec_qcompress")==0) 
+						{
+						    vc_qcompress = scanner->value.v_float;
+						}
+						else if (g_strcmp0(name,"vcodec_qblur")==0) 
+						{
+						    vc_qblur = scanner->value.v_float;
+						}
+						else
+						    printf("unexpected float value (%f) for %s\n", scanner->value.v_float, name);
 					}
 					else if (ttype==G_TOKEN_CHAR)
 					{
@@ -482,6 +635,35 @@ readConf(struct GLOBAL *global)
 		g_scanner_destroy (scanner);
 		close (fd);
 		
+		//get pointers to codec properties
+        vcodecs_data *vcodec_defaults = get_codec_defaults(global->VidCodec);
+        acodecs_data *acodec_defaults = get_aud_codec_defaults(get_ind_by4cc(global->Sound_Format));
+        
+        if (ac_bit_rate >= 0) acodec_defaults->bit_rate = ac_bit_rate;
+        if (vc_bit_rate >= 0) vcodec_defaults->bit_rate = vc_bit_rate;
+        if (vc_fps >= 0) vcodec_defaults->fps = vc_fps;
+		if (vc_qmax >= 0) vcodec_defaults->qmax = vc_qmax;
+		if (vc_qmin >= 0) vcodec_defaults->qmin = vc_qmin;
+		if (vc_max_qdiff >=0) vcodec_defaults->max_qdiff = vc_max_qdiff;
+		if (vc_dia >=0) vcodec_defaults->dia = vc_dia;
+		if (vc_pre_dia >=0) vcodec_defaults->pre_dia = vc_pre_dia;
+		if (vc_pre_me >=0) vcodec_defaults->pre_me = vc_pre_me;
+		if (vc_me_pre_cmp >=0) vcodec_defaults->me_pre_cmp = vc_me_pre_cmp;
+		if (vc_me_cmp >=0) vcodec_defaults->me_cmp = vc_me_cmp;
+		if (vc_me_sub_cmp >=0) vcodec_defaults->me_sub_cmp = vc_me_sub_cmp;
+		if (vc_last_pred >= 0) vcodec_defaults->last_pred = vc_last_pred;
+		if (vc_gop_size >= 0) vcodec_defaults->gop_size = vc_gop_size;
+		if (vc_subq >=0) vcodec_defaults->subq = vc_subq;
+		if (vc_framerefs >=0) vcodec_defaults->framerefs = vc_framerefs;
+		if (vc_mb_decision >=0) vcodec_defaults->mb_decision = vc_mb_decision;
+		if (vc_trellis >=0) vcodec_defaults->trellis = vc_trellis;
+		if (vc_me_method >=0) vcodec_defaults->me_method = vc_me_method;
+		if (vc_mpeg_quant >=0) vcodec_defaults->mpeg_quant = vc_mpeg_quant;
+		if (vc_max_b_frames >=0) vcodec_defaults->max_b_frames = vc_max_b_frames;
+        if (vc_flags >=0) vcodec_defaults->flags = vc_flags;
+        if (vc_qcompress >= 0) vcodec_defaults->qcompress = vc_qcompress;
+		if (vc_qblur >=0) vcodec_defaults->qblur = vc_qblur;
+        
 		if (global->debug) 
 		{
 			g_printf("video_device: %s\n",global->videodevice);
@@ -551,7 +733,7 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 		{ "capture_method", 'r', 0, G_OPTION_ARG_INT, &cap_meth, N_("Capture method (1-mmap (default)  2-read)"), "[1 | 2]"},
 		{ "config", 'g', 0, G_OPTION_ARG_STRING, &config, N_("Configuration file"), "FILENAME" },
 		{ "hwd_acel", 'w', 0, G_OPTION_ARG_INT, &hwaccel, N_("Hardware accelaration (enable(1) | disable(0))"), "[1 | 0]" },
-		{ "format", 'f', 0, G_OPTION_ARG_STRING, &format, N_("Pixel format(mjpg|jpeg|yuyv|yvyu|uyvy|yyuv|yu12|yv12|nv12|nv21|nv16|nv61|y41p|grey|s501|s505|s508|gbrg|grbg|ba81|rggb|bgr3|rgb3)"), "FORMAT" },
+		{ "format", 'f', 0, G_OPTION_ARG_STRING, &format, N_("Pixel format(mjpg|jpeg|yuyv|yvyu|uyvy|yyuv|yu12|yv12|nv12|nv21|nv16|nv61|y41p|grey|y16 |s501|s505|s508|gbrg|grbg|ba81|rggb|bgr3|rgb3)"), "FORMAT" },
 		{ "size", 's', 0, G_OPTION_ARG_STRING, &size, N_("Frame size, default: 640x480"), "WIDTHxHEIGHT"},
 		{ "image", 'i', 0, G_OPTION_ARG_STRING, &image, N_("Image File name"), "FILENAME"},
 		{ "cap_time", 'c', 0, G_OPTION_ARG_INT, &global->image_timer, N_("Image capture interval in seconds"), "TIME"},
@@ -559,7 +741,7 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 		{ "video", 'n', 0, G_OPTION_ARG_STRING, &video, N_("Video File name (capture from start)"), "FILENAME"},
 		{ "vid_time", 't', 0, G_OPTION_ARG_INT, &global->Capture_time,N_("Video capture time (in seconds)"), "TIME"},
 		{ "exit_on_close", 0, 0, G_OPTION_ARG_NONE, &global->exit_on_close, N_("Exits guvcview after closing video"), NULL},
-		{ "skip", 'j', 0, G_OPTION_ARG_INT, &global->skip_n, N_("Number of inital frames to skip"), "N_FRAMES"},
+		{ "skip", 'j', 0, G_OPTION_ARG_INT, &global->skip_n, N_("Number of initial frames to skip"), "N_FRAMES"},
 		{ "show_fps", 'p', 0, G_OPTION_ARG_INT, &FpsCount, N_("Show FPS value (enable(1) | disable (0))"), "[1 | 0]"},
 		{ "profile", 'l', 0, G_OPTION_ARG_STRING, &profile, N_("Load Profile at start"), "FILENAME"},
 		{ NULL }
@@ -694,9 +876,11 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 		else if (g_strcmp0("bggr",format)==0) // be compatible with guvcview < 1.1.4
 			g_snprintf(global->mode,5,"ba81");
 		else
-			g_snprintf(global->mode,5,"%s",format);
+			g_snprintf(global->mode,5,"%s ",format);
+			
+	    printf("requested format \"%s\" from command line\n", global->mode);
 		
-		global->flg_mode = 1;
+		global->flg_mode = TRUE;
 	}
 	if(size)
 	{
@@ -720,18 +904,17 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 		global->imgFPath=splitPath(image,global->imgFPath);
 		/*get the file type*/
 		global->imgFormat = check_image_type(global->imgFPath[0]);
-		global->flg_imgFPath = 1;
+		global->flg_imgFPath = TRUE;
 	}
 	if(global->image_timer > 0 )
 	{
-		global->image_inc=1;
-		g_printf("capturing images every %i seconds",global->image_timer);
+		g_printf("capturing images every %i seconds\n",global->image_timer);
 	}
 	if(video)
 	{
 		global->vidfile = g_strdup(video);
 		global->vidFPath=splitPath(global->vidfile,global->vidFPath);
-		g_printf("capturing video: %s , from start",global->vidfile);
+		g_printf("capturing video: %s , from start\n",global->vidfile);
 		/*get the file type*/
 		global->VidFormat = check_video_type(global->vidFPath[0]);
 	}
