@@ -74,9 +74,7 @@
                                  UVC_CONTROL_GET_MAX | UVC_CONTROL_GET_RES | \
                                  UVC_CONTROL_GET_DEF)
 
-
-struct uvc_xu_control_info 
-{
+struct uvc_xu_control_info {
 	__u8 entity[16];
 	__u8 index;
 	__u8 selector;
@@ -84,33 +82,30 @@ struct uvc_xu_control_info
 	__u32 flags;
 };
 
-struct uvc_xu_control_mapping 
-{
+struct uvc_xu_control_mapping {
 	__u32 id;
 	__u8 name[32];
 	__u8 entity[16];
 	__u8 selector;
-  
+
 	__u8 size;
 	__u8 offset;
 	enum v4l2_ctrl_type v4l2_type;
 	__u32 data_type;
 };
 
-struct uvc_xu_control 
-{
+struct uvc_xu_control {
 	__u8 unit;
 	__u8 selector;
 	__u16 size;
-	//__u8 __user *data;
 	__u8 *data;
 };
 
-#define UVCIOC_CTRL_ADD		_IOW  ('U', 1, struct uvc_xu_control_info)
-#define UVCIOC_CTRL_MAP		_IOWR ('U', 2, struct uvc_xu_control_mapping)
-#define UVCIOC_CTRL_GET		_IOWR ('U', 3, struct uvc_xu_control)
-#define UVCIOC_CTRL_SET		_IOW  ('U', 4, struct uvc_xu_control)
+#define UVCIOC_CTRL_ADD		_IOW('U', 1, struct uvc_xu_control_info)
+#define UVCIOC_CTRL_MAP		_IOWR('U', 2, struct uvc_xu_control_mapping)
+#define UVCIOC_CTRL_GET		_IOWR('U', 3, struct uvc_xu_control)
+#define UVCIOC_CTRL_SET		_IOW('U', 4, struct uvc_xu_control)
 
 int initDynCtrls(int fd);
 
-#endif
\ No newline at end of file
+#endif
