@@ -602,6 +602,14 @@ static int videoIn_frame_alloca(struct vdIn *vd, int format, int width, int heig
 			vd->framebuffer = g_new0(unsigned char, framebuf_size);
 			break;
 			
+	    case V4L2_PIX_FMT_Y16:
+			// alloc a temp buffer for converting to YUYV
+			tmpbuf_size= width * height * 2; // 2 byte per pixel
+			vd->tmpbuffer = g_new0(unsigned char, tmpbuf_size);
+			framebuf_size = framesizeIn;
+			vd->framebuffer = g_new0(unsigned char, framebuf_size);
+			break;
+			
 		case V4L2_PIX_FMT_YUYV:
 			//  YUYV doesn't need a temp buffer but we will set it if/when
 			//  video processing disable control is checked (bayer processing).
@@ -685,7 +693,10 @@ int init_videoIn(struct vdIn *vd, struct GLOBAL *global)
 {
 	int ret = VDIN_OK;
 	char *device = global->videodevice;
-	
+    
+    /* Create a udev object */
+    vd->udev = udev_new();
+
 	vd->mutex = g_mutex_new();
 	if (vd == NULL || device == NULL)
 		return VDIN_ALLOC_ERR;
@@ -726,8 +737,19 @@ int init_videoIn(struct vdIn *vd, struct GLOBAL *global)
 	
 	vd->tmpbuffer = NULL;
 	vd->framebuffer = NULL;
+	
+    /*start udev device monitoring*/
+    /* Set up a monitor to monitor v4l2 devices */
+    if(vd->udev)
+    {
+        vd->udev_mon = udev_monitor_new_from_netlink(vd->udev, "udev");
+        udev_monitor_filter_add_match_subsystem_devtype(vd->udev_mon, "video4linux", NULL);
+        udev_monitor_enable_receiving(vd->udev_mon);
+        /* Get the file descriptor (fd) for the monitor */
+        vd->udev_fd = udev_monitor_get_fd(vd->udev_mon);
+    }
 
-	vd->listDevices = enum_devices( vd->videodevice );
+    vd->listDevices = enum_devices( vd->videodevice, vd->udev, (int) global->debug);
 	
 	if (vd->listDevices != NULL)
 	{
@@ -915,6 +937,11 @@ static int frame_decode(struct vdIn *vd, int format, int width, int height)
 			grey_to_yuyv(vd->framebuffer, vd->tmpbuffer, width, height);
 			break;
 			
+	    case V4L2_PIX_FMT_Y16:
+			memcpy(vd->tmpbuffer, vd->mem[vd->buf.index],vd->buf.bytesused);
+			y16_to_yuyv(vd->framebuffer, vd->tmpbuffer, width, height);
+			break;
+			
 		case V4L2_PIX_FMT_SPCA501:
 			memcpy(vd->tmpbuffer, vd->mem[vd->buf.index],vd->buf.bytesused);
 			s501_to_yuyv(vd->framebuffer, vd->tmpbuffer, width, height);
@@ -1101,7 +1128,7 @@ int uvcGrab(struct vdIn *vd, int format, int width, int height, int *fps, int *f
 					memset(&vd->buf, 0, sizeof(struct v4l2_buffer));
 					vd->buf.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 					vd->buf.memory = V4L2_MEMORY_MMAP;
-
+                    
 					ret = xioctl(vd->fd, VIDIOC_DQBUF, &vd->buf);
 					if (ret < 0) 
 					{
@@ -1109,11 +1136,13 @@ int uvcGrab(struct vdIn *vd, int format, int width, int height, int *fps, int *f
 						ret = VDIN_DEQBUFS_ERR;
 						return ret;
 					}
-					ts = (UINT64) vd->buf.timestamp.tv_sec * G_NSEC_PER_SEC +  vd->buf.timestamp.tv_usec * 1000; //in nanosec
+					ts = (UINT64) vd->buf.timestamp.tv_sec * G_NSEC_PER_SEC +  
+					    vd->buf.timestamp.tv_usec * 1000; //in nanosec
+					    
 					/* use buffer timestamp if set by the driver, otherwise use current system time */
 					if(ts > 0) vd->timestamp = ts; 
 					else vd->timestamp = ns_time_monotonic(); 
-				
+
 					ret = xioctl(vd->fd, VIDIOC_QBUF, &vd->buf);
 					if (ret < 0) 
 					{
@@ -1217,7 +1246,9 @@ error:
 void close_v4l2(struct vdIn *vd, gboolean control_only)
 {
 	if (vd->isstreaming) video_disable(vd);
-	
+
+    if (vd->udev) udev_unref(vd->udev);
+
 	if(vd->videodevice) g_free(vd->videodevice);
 	if(vd->ImageFName)g_free(vd->ImageFName);
 	if(vd->VidFName)g_free(vd->VidFName);
